# Script to read a MAC address from an Ethernet device built into the platform and set it in the Windows registry to be used by a DisplayLink Ethernet device
# More information here: http://support.displaylink.com/knowledgebase/articles/613455#remote

# Get the Built in Adapter MAC Address
# Takes the MAC Address of the first adapters it finds
$nics = @(Get-WmiObject -Query "select * from win32_networkadapter where adaptertype != 'Tunnel' and adaptertype is not null" | `
where { $_.description -notmatch 'VMware|Virtual|WAN Miniport|ISATAP|RAS Async|Teredo|Windows Mobile Remote|6to4|Bluetooth|DisplayLink|TAP-Windows|VPN|Sophos' } |Select-Object -first 1 )
# Write-Host $nics.MacAddress
$macAddress = $nics.MACAddress | Out-String

echo "Direccion MAC PC $macAddress"

# Remove the separators from the MAC address string
$macAddress = $macAddress -replace '[:]'

# Write the MAC address into the Windows registry, to be used by any DisplayLink Ethernet adapter connected
$regPath = "HKLM:\System\CurrentControlSet\services\dlcdcncm\Parameters\"
$Name = 'MacAddressOverride'

# Check if the path exists, and create it if it does not
if (!(Test-Path $regPath)) {
    New-Item -Path $regPath -Force | Out-Null
} 

New-ItemProperty -Path $regPath -Name $Name -Value $macAddress -Force | Out-Null


#$nics3 = @(Get-WmiObject -Query "select * from win32_networkadapter where adaptertype != 'Tunnel' and adaptertype is not null" | `
#where { $_.description -match 'DisplayLink' } | Select-Object -first 1 )

#echo $nics3